/*!
* Copyright Adaptavist 2022 (c) All rights reserved
*/
import { FormData, Blob, Request, Response, BaseApiCore, constructUrl, executeHttpCall } from '@managed-api/commons-core';
import { constructHeaders, errorMessageBuilder } from './common';
import { customErrorHandlers, errorStrategyBuilderConstructor } from './errorStrategy';
export class JiraServiceManagementOnPremiseApiCore extends BaseApiCore {
    constructor(options) {
        super();
        this.options = options;
        if (!this.options?.errorStrategy && this.options?.errorStrategy !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Customer = new CustomerGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Info = new InfoGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Organization = new OrganizationGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Portal = new PortalGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Queue = new QueueGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Request = new RequestGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Servicedesk = new ServicedeskGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Customer, this.Info, this.Organization, this.Portal, this.Queue, this.Request, this.Servicedesk);
    }
    setGlobalErrorStrategy(errorStrategy) {
        this.options = {
            ...this.options ?? {},
            errorStrategy
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        return this.options?.errorStrategy;
    }
}
class AllGroup {
    constructor(Customer, Info, Organization, Portal, Queue, Request, Servicedesk) {
        this.Customer = Customer;
        this.Info = Info;
        this.Organization = Organization;
        this.Portal = Portal;
        this.Queue = Queue;
        this.Request = Request;
        this.Servicedesk = Servicedesk;
    }
    /**
     * Creates a customer that is not associated with a service project.
     * The customer's username is their email address. They can set a password by clicking "Forgotten your password" on the portal login screen, or a Jira administrator can set one in User Management. By default, the customer can email requests to public service projects. If they have a password, they can also raise requests in customer portals that allow public signup. To raise requests in closed service projects, the customer must be added to a service project using Add customers.
     * This operation does not cause invitation email to be sent to the newly created customer.
     * Jira administrator global permission is required to create a customer.
     * Alternative usage: Customer.createCustomer
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/customer-createCustomer
     * @param options Request options.
     */
    async createCustomer(options) {
        return this.Customer.createCustomer(options);
    }
    /**
     * Returns runtime information about Jira Service Management.
     * You do not need to be logged in to use this method.
     * Alternative usage: Customer.getInfo
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/info-getInfo
     * @param options Request options.
     */
    async getInfo(options) {
        return this.Info.getInfo(options);
    }
    /**
     * Get all portals. Returns a maximum of 50 portals per page
     * Alternative usage: Portal.getPortals
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/portals-getPortals
     * @param options Request options.
     */
    async getPortals(options) {
        return this.Portal.getPortals(options);
    }
    /**
     * Get a portal with the specified project key.
     * Alternative usage: Portal.getPortalByProjectKey
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/portals-getPortal
     * @param options Request options.
     */
    async getPortalByProjectKey(options) {
        return this.Portal.getPortalByProjectKey(options);
    }
    /**
     * Get a portal with the specified ID.
     * Alternative usage: Portal.getPortalById
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/portals-getPortal
     * @param options Request options.
     */
    async getPortalById(options) {
        return this.Portal.getPortalById(options);
    }
    /**
     * Get queue settings on project
     * Alternative usage: Queue.getQueueSettings
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-getQueueSettingsOnProject
     * @param options Request options.
     */
    async getQueueSettings(options) {
        return this.Queue.getQueueSettings(options);
    }
    /**
     * Set should queues use count cache on project
     * Alternative usage: Queue.setQueuesUseCountCacheOnProject
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesUseCountCacheOnProject
     * @param options Request options.
     */
    async setQueuesUseCountCacheOnProject(options) {
        return this.Queue.setQueuesUseCountCacheOnProject(options);
    }
    /**
     * Set should queues include count on project
     * Alternative usage: Queue.setQueuesIncludeCountOnProject
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesIncludeCountOnProject
     * @param options Request options.
     */
    async setQueuesIncludeCountOnProject(options) {
        return this.Queue.setQueuesIncludeCountOnProject(options);
    }
    /**
     * Set should queues use count cache globally
     * Alternative usage: Queue.setQueuesUseCountCacheGlobal
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesUseCountCacheGlobally
     * @param options Request options.
     */
    async setQueuesUseCountCacheGlobal(options) {
        return this.Queue.setQueuesUseCountCacheGlobal(options);
    }
    /**
     * Set should queues include count globally
     * Alternative usage: Queue.setQueuesIncludeCountGlobal
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesIncludeCountGlobally
     * @param options Request options.
     */
    async setQueuesIncludeCountGlobal(options) {
        return this.Queue.setQueuesIncludeCountGlobal(options);
    }
    /**
     * To create an organization Jira administrator global permission or agent permission is required depending on the settings
     * Alternative usage: Organization.createOrganization
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-createOrganization
     * @param options Request options.
     */
    async createOrganization(options) {
        return this.Organization.createOrganization(options);
    }
    /**
     * Returns a list of organizations in the Jira instance.
     * If the user is not an agent, the resource returns a list of organizations the user is a member of.
     * Alternative usage: Organization.getOrganizations
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-getOrganizations
     * @param options Request options.
     */
    async getOrganizations(options) {
        return this.Organization.getOrganizations(options);
    }
    /**
     * Returns an organization for a given organization ID.
     * Alternative usage: Organization.getOrganization
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-getOrganization
     * @param options Request options.
     */
    async getOrganization(options) {
        return this.Organization.getOrganization(options);
    }
    /**
     * Deletes an organization for a given organization ID.
     * Alternative usage: Organization.deleteOrganization
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-deleteOrganization
     * @param options Request options.
     */
    async deleteOrganization(options) {
        return this.Organization.deleteOrganization(options);
    }
    /**
     * Returns all the users of a specified organization.
     * Alternative usage: Organization.User.getUsers
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-getUsersInOrganization
     * @param options Request options.
     */
    async getOrganizationUsers(options) {
        return this.Organization.User.getUsers(options);
    }
    /**
     * Adds users to an organization.
     * Alternative usage: Organization.User.addUsers
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-addUsersToOrganization
     * @param options Request options.
     */
    async addOrganizationUsers(options) {
        return this.Organization.User.addUsers(options);
    }
    /**
     * Removes users from an organization.
     * Alternative usage: Organization.User.removeUsers
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-removeUsersFromOrganization
     * @param options Request options.
     */
    async removeOrganizationUsers(options) {
        return this.Organization.User.removeUsers(options);
    }
    /**
     * Creates a customer request in a service project.
     * The service project and request type are required.
     * The fields that are mandatory for the request type are also required. If you need the list of the fields required for the request type, you can get it via this resource:
     * https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype/{requestTypeId}/field
     * Alternative usage: Request.createRequest
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request-createCustomerRequest
     * @param options Request options.
     */
    async createRequest(options) {
        return this.Request.createRequest(options);
    }
    /**
     * Returns all customer requests for the user that is executing the query.
     * That is, the customer requests where the user is the creator of the customer request or has participated in the customer request.
     * Returned customer requests are ordered chronologically by the latest activity on each customer request. For example, the latest status transition or comment.
     * Alternative usage: Request.getRequests
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request-getMyCustomerRequests
     * @param options Request options.
     */
    async getRequests(options) {
        return this.Request.getRequests(options);
    }
    /**
     * Returns the customer request for a given request Id/key.
     * Alternative usage: Request.getRequest
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request-getCustomerRequestByIdOrKey
     * @param options Request options.
     */
    async getRequest(options) {
        return this.Request.getRequest(options);
    }
    /**
     * Returns all approvals on a request, for a given request Id/key.
     * Alternative usage: Request.Approval.getApprovals
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/approval-getApprovals
     * @param options Request options.
     */
    async getRequestApprovals(options) {
        return this.Request.Approval.getApprovals(options);
    }
    /**
     * Answer a pending approval.
     * Alternative usage: Request.Approval.answerApproval
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/approval-answerApproval
     * @param options Request options.
     */
    async answerRequestApproval(options) {
        return this.Request.Approval.answerApproval(options);
    }
    /**
     * Returns an approval for a given approval ID.
     * Alternative usage: Request.Approval.getApproval
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/approval-getApprovalById
     * @param options Request options.
     */
    async getRequestApproval(options) {
        return this.Request.Approval.getApproval(options);
    }
    /**
     * Adds one or more temporary attachments that were created using Attach temporary file to a customer request. The attachment visibility is set by the public field.
     * Setting attachment visibility is dependent on the user's permission.
     * For example, Agents can create either public or internal attachments, while Unlicensed users can only create internal attachments, and Customers can only create public attachments.
     * An additional comment may be provided which will be prepended to the attachments.
     * Alternative usage: Request.Attachment.createAttachment
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/attachment-createAttachment
     * @param options Request options.
     */
    async createRequestAttachment(options) {
        return this.Request.Attachment.createAttachment(options);
    }
    /**
     * Returns all comments on a customer request, for a given request Id/key.
     * Alternative usage: Request.Comment.getComments
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/comment-getRequestComments
     * @param options Request options.
     */
    async getRequestComments(options) {
        return this.Request.Comment.getComments(options);
    }
    /**
     * Creates a public or internal comment on an existing customer request.
     * The currently logged-in user will be the author of the comment.
     * The comment visibility is set by the public field.
     * Alternative usage: Request.Comment.createComment
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/comment-createRequestComment
     * @param options Request options.
     */
    async createRequestComment(options) {
        return this.Request.Comment.createComment(options);
    }
    /**
     * Returns a specific comment of a specific customer request based on the provided comment ID.
     * Alternative usage: Request.Comment.getComment
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/comment-getRequestCommentById
     * @param options Request options.
     */
    async getRequestComment(options) {
        return this.Request.Comment.getComment(options);
    }
    /**
     * Returns all users participating in a customer request, for a given request Id/key.
     * Alternative usage: Request.Participant.getParticipants
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/participant-getRequestParticipants
     * @param options Request options.
     */
    async getRequestParticipants(options) {
        return this.Request.Participant.getParticipants(options);
    }
    /**
     * Adds users as participants to an existing customer request.
     * Note, you can also add participants when creating a request via the request resource, by using the requestParticipants field.
     * Alternative usage: Request.Participant.addParticipants
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/participant-addRequestParticipants
     * @param options Request options.
     */
    async addRequestParticipants(options) {
        return this.Request.Participant.addParticipants(options);
    }
    /**
     * Removes participants from an existing customer request.
     * Alternative usage: Request.Participant.removeParticipants
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/participant-removeRequestParticipants
     * @param options Request options.
     */
    async removeRequestParticipants(options) {
        return this.Request.Participant.removeParticipants(options);
    }
    /**
     * Returns the SLA information for a customer request for a given request Id/key.
     * A request can have zero or more SLA values.
     * Each SLA value can have zero or more "completed cycles" and zero or 1 "ongoing cycles".
     * Each cycle has information on when it started and stopped, and whether it breached the SLA goal.
     * Alternative usage: Request.SLA.getInfo
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/sla-getSlaInformation
     * @param options Request options.
     */
    async getSLAInfo(options) {
        return this.Request.SLA.getInfo(options);
    }
    /**
     * Returns the SLA information for a customer request for a given request Id/key and SLA metric Id.
     * A request can have zero or more SLA values.
     * Each SLA value can have zero or more "completed cycles" and zero or 1 "ongoing cycles".
     * Each cycle has information on when it started and stopped, and whether it breached the SLA goal.
     * Alternative usage: Request.SLA.getInfoById
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/sla-getSlaInformationById
     * @param options Request options.
     */
    async getSLAInfoById(options) {
        return this.Request.SLA.getInfoById(options);
    }
    /**
     * Returns the status transitions for a customer request for a given request Id/key.
     * The status transitions are returned in chronological order.
     * Alternative usage: Request.Status.getStatus
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/status-getCustomerRequestStatus
     * @param options Request options.
     */
    async getRequestStatus(options) {
        return this.Request.Status.getStatus(options);
    }
    /**
     * Returns a list of transitions that customers can perform on the request.
     * Alternative usage: Request.Transition.getTransitions
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/transition-getCustomerTransitions
     * @param options Request options.
     */
    async getRequestTransitions(options) {
        return this.Request.Transition.getTransitions(options);
    }
    /**
     * Perform a customer transition for a given request and transition ID.
     * An optional comment can be included to provide a reason for the transition.
     * Alternative usage: Request.Transition.performTransition
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/transition-performCustomerTransition
     * @param options Request options.
     */
    async performRequestTransition(options) {
        return this.Request.Transition.performTransition(options);
    }
    /**
     * Returns all service projects in the Jira Service Management application with the option to include archived service projects.
     * Alternative usage: Servicedesk.getServicedesks
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk-getServiceDesks
     * @param options Request options.
     */
    async getServicedesks(options) {
        return this.Servicedesk.getServicedesks(options);
    }
    /**
     * Returns the service project for a given service project Id.
     * Alternative usage: Servicedesk.getServicedesk
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk-getServiceDeskById
     * @param options Request options.
     */
    async getServicedesk(options) {
        return this.Servicedesk.getServicedesk(options);
    }
    /**
     * Create one or more temporary attachments, which can later be converted into permanent attachments on Create attachment:
     * https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/attachment
     * On successful execution, this resource will return a list of temporary attachment IDs, which are used in subsequent calls to convert the attachments into permanent attachments.
     * Alternative usage: Servicedesk.addTemporaryFile
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/attachTemporaryFile-attachTemporaryFile
     * @param options Request options.
     */
    async addTemporaryFileToServicedesk(options) {
        return this.Servicedesk.addTemporaryFile(options);
    }
    /**
     * Adds one or more existing customers to the given service project. If you need to create a customer, see Create customer:
     * https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/customer
     * Administer project permission is required, or agents if public signups and invites are enabled for the service project.
     * Alternative usage: Servicedesk.Customer.addCustomers
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/customer-addCustomers
     * @param options Request options.
     */
    async addCustomersToServicedesk(options) {
        return this.Servicedesk.Customer.addCustomers(options);
    }
    /**
     * Adds an organization to a service project for a given service project id and organization id.
     * Alternative usage: Servicedesk.Organization.addOrganization
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/organization-addOrganization
     * @param options Request options.
     */
    async addServicedeskOrganization(options) {
        return this.Servicedesk.Organization.addOrganization(options);
    }
    /**
     * Removes an organization from a service project for a given service project id and organization id.
     * Alternative usage: Servicedesk.Organization.removeOrganization
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/organization-removeOrganization
     * @param options Request options.
     */
    async removeServicedeskOrganization(options) {
        return this.Servicedesk.Organization.removeOrganization(options);
    }
    /**
     * Returns all organizations within a service project for a given service project id.
     * Alternative usage: Servicedesk.Organization.getOrganizations
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/organization-getOrganizations
     * @param options Request options.
     */
    async getServicedeskOrganizations(options) {
        return this.Servicedesk.Organization.getOrganizations(options);
    }
    /**
     * Returns a page of queues defined inside a service project, for a given service project ID.
     * The returned queues will include an issue count for each queue (represented in issueCount field) if the query param includeCount is set to true (defaults to false).
     * Alternative usage: Servicedesk.Queue.getQueues
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-getQueues
     * @param options Request options.
     */
    async getServicedeckQueues(options) {
        return this.Servicedesk.Queue.getQueues(options);
    }
    /**
     * Creates a queue with the given properties.
     * Alternative usage: Servicedesk.Queue.createQueue
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-createQueue
     * @param options Request options.
     */
    async createServicedeckQueue(options) {
        return this.Servicedesk.Queue.createQueue(options);
    }
    /**
     * Reorder queues for the users. This is the order in which the queues will appear in agent view.
     * The API requires all queue ids to be passed in the new order.
     * Alternative usage: Servicedesk.Queue.reorderQueues
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-reorderQueues
     * @param options Request options.
     */
    async reorderServicedeckQueue(options) {
        return this.Servicedesk.Queue.reorderQueues(options);
    }
    /**
     * Updates the queue properties with the new properties. If a property is not passed it will not be updated.
     * Alternative usage: Servicedesk.Queue.updateQueue
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-updateQueue
     * @param options Request options.
     */
    async updateServicedeckQueue(options) {
        return this.Servicedesk.Queue.updateQueue(options);
    }
    /**
     * Delete the queue for the given queue id.
     * Alternative usage: Servicedesk.Queue.deleteQueue
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-deleteQueue
     * @param options Request options.
     */
    async deleteServicedeckQueue(options) {
        return this.Servicedesk.Queue.deleteQueue(options);
    }
    /**
     * Returns the queue for a given service project id and queue id.
     * The returned queue will include an issue count for queue (represented in issueCount field) if the query param includeCount is set to true (defaults to false).
     * Alternative usage: Servicedesk.Queue.getQueue
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-getQueue
     * @param options Request options.
     */
    async getServicedeckQueue(options) {
        return this.Servicedesk.Queue.getQueue(options);
    }
    /**
     * Returns a page of issues inside a queue for a given queue ID.
     * Only fields that the queue is configured to show are returned. For example, if a queue is configured to show only Description and Due Date, then only those two fields are returned for each issue in the queue.
     * Alternative usage: Servicedesk.Queue.getIssuesInQueue
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-getIssuesInQueue
     * @param options Request options.
     */
    async getServicedeskIssuesInQueue(options) {
        return this.Servicedesk.Queue.getIssuesInQueue(options);
    }
    /**
     * Returns all request types from a service project, for a given service project Id.
     * Alternative usage: Servicedesk.Request.Type.getTypes
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype-getRequestTypes
     * @param options Request options.
     */
    async getServicedeskRequestTypes(options) {
        return this.Servicedesk.Request.Type.getTypes(options);
    }
    /**
     * Creates a new request type for a given service project.
     * Certain fields cannot be specified on creation. These fields are given default values instead, as shown below.
     * Request Type icon - Question mark icon
     * Request Type groups - Empty, i.e. this request type will be hidden by default and not visible on the customer portal
     * Request Type status mapping - Empty, i.e. no custom status mapping
     * Request Type field mapping - Show the required fields as specified by the issue type
     * These fields can be updated after creation by a project administrator using the Agent view.
     * Alternative usage: Servicedesk.Request.Type.createType
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype-createRequestType
     * @param options Request options.
     */
    async createServicedeskRequestType(options) {
        return this.Servicedesk.Request.Type.createType(options);
    }
    /**
     * Returns a request type for a given request type Id.
     * Alternative usage: Servicedesk.Request.Type.getType
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype-getRequestTypeById
     * @param options Request options.
     */
    async getServicedeskRequestType(options) {
        return this.Servicedesk.Request.Type.getType(options);
    }
    /**
     * Returns the fields for a request type, for a given request type Id and service project Id. These are the fields that are required to create a customer request of that particular request type.
     * In addition, the following information about the current user's permissions for the request type is returned:
     * * canRaiseOnBehalfOf field - Returns true, if the user has permission to raise requests on behalf of customers. Otherwise, returns false.
     * * canAddRequestParticipants field - Returns true, if the user can add request participants. Otherwise, returns false.
     * Alternative usage: Servicedesk.Request.Type.getFields
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype/{requestTypeId}/field-getRequestTypeFields
     * @param options Request options.
     */
    async getServicedeskRequestTypeFields(options) {
        return this.Servicedesk.Request.Type.getFields(options);
    }
    /**
     * Returns all request type groups from a service project, for a given service project Id.
     * The groups will be in the same order as the order in which they appear on the customer portal
     * Alternative usage: Servicedesk.Request.Type.getTypeGroups
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttypegroup-getRequestTypeGroups
     * @param options Request options.
     */
    async getServicedeskRequestTypeGroups(options) {
        return this.Servicedesk.Request.Type.getTypeGroups(options);
    }
}
class CustomerGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Creates a customer that is not associated with a service project.
     * The customer's username is their email address. They can set a password by clicking "Forgotten your password" on the portal login screen, or a Jira administrator can set one in User Management. By default, the customer can email requests to public service projects. If they have a password, they can also raise requests in customer portals that allow public signup. To raise requests in closed service projects, the customer must be added to a service project using Add customers.
     * This operation does not cause invitation email to be sent to the newly created customer.
     * Jira administrator global permission is required to create a customer.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/customer-createCustomer
     * @param options Request options.
     */
    async createCustomer(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request('POST', '/rest/servicedeskapi/customer', constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class InfoGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns runtime information about Jira Service Management.
     * You do not need to be logged in to use this method.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/info-getInfo
     * @param options Request options.
     */
    async getInfo(options) {
        const { headers, errorStrategy } = options ?? {};
        const request = new Request('GET', '/rest/servicedeskapi/info', constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class PortalGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get all portals. Returns a maximum of 50 portals per page
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/portals-getPortals
     * @param options Request options.
     */
    async getPortals(options) {
        const { start, limit, headers, errorStrategy } = options ?? {};
        const queryParams = { start, limit };
        const request = new Request('GET', constructUrl('/rest/servicedeskapi/portals', queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a portal with the specified project key.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/portals-getPortal
     * @param options Request options.
     */
    async getPortalByProjectKey(options) {
        const { projectKey, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/servicedeskapi/portals/project/${encodeURIComponent(projectKey)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Get a portal with the specified ID.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/portals-getPortal
     * @param options Request options.
     */
    async getPortalById(options) {
        const { portalId, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/servicedeskapi/portals/${encodeURIComponent(portalId)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class QueueGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Get queue settings on project
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-getQueueSettingsOnProject
     * @param options Request options.
     */
    async getQueueSettings(options) {
        const { projectKey, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/servicedeskapi/queues/${encodeURIComponent(projectKey)}`, constructHeaders(null, { 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Set should queues use count cache on project
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesUseCountCacheOnProject
     * @param options Request options.
     */
    async setQueuesUseCountCacheOnProject(options) {
        const { projectKey, body, headers, errorStrategy } = options;
        const request = new Request('PUT', `/rest/servicedeskapi/queues/${encodeURIComponent(projectKey)}/cache-count`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', 'Content-Type': 'application/json; charset=utf-8', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Set should queues include count on project
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesIncludeCountOnProject
     * @param options Request options.
     */
    async setQueuesIncludeCountOnProject(options) {
        const { projectKey, body, headers, errorStrategy } = options;
        const request = new Request('PUT', `/rest/servicedeskapi/queues/${encodeURIComponent(projectKey)}/include-count`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', 'Content-Type': 'application/json; charset=utf-8', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Set should queues use count cache globally
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesUseCountCacheGlobally
     * @param options Request options.
     */
    async setQueuesUseCountCacheGlobal(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request('PUT', '/rest/servicedeskapi/queues/cache-count', constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', 'Content-Type': 'application/json; charset=utf-8', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Set should queues include count globally
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/queues-setShouldQueuesIncludeCountGlobally
     * @param options Request options.
     */
    async setQueuesIncludeCountGlobal(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request('PUT', '/rest/servicedeskapi/queues/include-count', constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', 'Content-Type': 'application/json; charset=utf-8', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class OrganizationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.User = new OrganizationUserGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * To create an organization Jira administrator global permission or agent permission is required depending on the settings
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-createOrganization
     * @param options Request options.
     */
    async createOrganization(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request('POST', '/rest/servicedeskapi/organization', constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns a list of organizations in the Jira instance.
     * If the user is not an agent, the resource returns a list of organizations the user is a member of.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-getOrganizations
     * @param options Request options.
     */
    async getOrganizations(options) {
        const { start, limit, headers, errorStrategy } = options ?? {};
        const queryParams = { start, limit };
        const request = new Request('GET', constructUrl('/rest/servicedeskapi/organization', queryParams), constructHeaders(null, { 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns an organization for a given organization ID.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-getOrganization
     * @param options Request options.
     */
    async getOrganization(options) {
        const { organizationId, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}`, constructHeaders({ 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Deletes an organization for a given organization ID.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-deleteOrganization
     * @param options Request options.
     */
    async deleteOrganization(options) {
        const { organizationId, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}`, constructHeaders({ 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class OrganizationUserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns all the users of a specified organization.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-getUsersInOrganization
     * @param options Request options.
     */
    async getUsers(options) {
        const { organizationId, start, limit, headers, errorStrategy } = options;
        const queryParams = { start, limit };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}/user`, queryParams), constructHeaders(null, { 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Adds users to an organization.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-addUsersToOrganization
     * @param options Request options.
     */
    async addUsers(options) {
        const { organizationId, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}/user`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Removes users from an organization.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/organization-removeUsersFromOrganization
     * @param options Request options.
     */
    async removeUsers(options) {
        const { organizationId, body, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/rest/servicedeskapi/organization/${encodeURIComponent(organizationId)}/user`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class RequestGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Approval = new RequestApprovalGroup(implementation, this.getGlobalErrorStrategy);
        this.Attachment = new RequestAttachmentGroup(implementation, this.getGlobalErrorStrategy);
        this.Comment = new RequestCommentGroup(implementation, this.getGlobalErrorStrategy);
        this.Participant = new RequestParticipantGroup(implementation, this.getGlobalErrorStrategy);
        this.SLA = new RequestSLAGroup(implementation, this.getGlobalErrorStrategy);
        this.Status = new RequestStatusGroup(implementation, this.getGlobalErrorStrategy);
        this.Transition = new RequestTransitionGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Creates a customer request in a service project.
     * The service project and request type are required.
     * The fields that are mandatory for the request type are also required. If you need the list of the fields required for the request type, you can get it via this resource:
     * https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype/{requestTypeId}/field
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request-createCustomerRequest
     * @param options Request options.
     */
    async createRequest(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request('POST', '/rest/servicedeskapi/request', constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns all customer requests for the user that is executing the query.
     * That is, the customer requests where the user is the creator of the customer request or has participated in the customer request.
     * Returned customer requests are ordered chronologically by the latest activity on each customer request. For example, the latest status transition or comment.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request-getMyCustomerRequests
     * @param options Request options.
     */
    async getRequests(options) {
        const { searchTerm, requestOwnership, requestStatus, serviceDeskId, requestTypeId, expand, start, limit, headers, errorStrategy } = options ?? {};
        const queryParams = { searchTerm, requestOwnership, requestStatus, serviceDeskId, requestTypeId, expand, start, limit };
        const request = new Request('GET', constructUrl('/rest/servicedeskapi/request', queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns the customer request for a given request Id/key.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request-getCustomerRequestByIdOrKey
     * @param options Request options.
     */
    async getRequest(options) {
        const { issueIdOrKey, expand, headers, errorStrategy } = options;
        const queryParams = { expand };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestApprovalGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns all approvals on a request, for a given request Id/key.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/approval-getApprovals
     * @param options Request options.
     */
    async getApprovals(options) {
        const { issueIdOrKey, start, limit, headers, errorStrategy } = options;
        const queryParams = { start, limit };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/approval`, queryParams), constructHeaders(null, { 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Answer a pending approval.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/approval-answerApproval
     * @param options Request options.
     */
    async answerApproval(options) {
        const { issueIdOrKey, approvalId, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/servicedeskapi/request${encodeURIComponent(issueIdOrKey)}/approval/${encodeURIComponent(approvalId)}`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns an approval for a given approval ID.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/approval-getApprovalById
     * @param options Request options.
     */
    async getApproval(options) {
        const { issueIdOrKey, approvalId, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/servicedeskapi/request${encodeURIComponent(issueIdOrKey)}/approval/${encodeURIComponent(approvalId)}`, constructHeaders(null, { 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestAttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Adds one or more temporary attachments that were created using Attach temporary file to a customer request. The attachment visibility is set by the public field.
     * Setting attachment visibility is dependent on the user's permission.
     * For example, Agents can create either public or internal attachments, while Unlicensed users can only create internal attachments, and Customers can only create public attachments.
     * An additional comment may be provided which will be prepended to the attachments.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/attachment-createAttachment
     * @param options Request options.
     */
    async createAttachment(options) {
        const { issueIdOrKey, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/attachment`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns all comments on a customer request, for a given request Id/key.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/comment-getRequestComments
     * @param options Request options.
     */
    async getComments(options) {
        const { issueIdOrKey, internal, start, limit, headers, errorStrategy } = options;
        const queryParams = { public: options.public, internal, start, limit };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/comment`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a public or internal comment on an existing customer request.
     * The currently logged-in user will be the author of the comment.
     * The comment visibility is set by the public field.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/comment-createRequestComment
     * @param options Request options.
     */
    async createComment(options) {
        const { issueIdOrKey, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/comment`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns a specific comment of a specific customer request based on the provided comment ID.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/comment-getRequestCommentById
     * @param options Request options.
     */
    async getComment(options) {
        const { issueIdOrKey, commentId, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/comment/${encodeURIComponent(commentId)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestParticipantGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns all users participating in a customer request, for a given request Id/key.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/participant-getRequestParticipants
     * @param options Request options.
     */
    async getParticipants(options) {
        const { issueIdOrKey, start, limit, headers, errorStrategy } = options;
        const queryParams = { start, limit };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/participant`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Adds users as participants to an existing customer request.
     * Note, you can also add participants when creating a request via the request resource, by using the requestParticipants field.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/participant-addRequestParticipants
     * @param options Request options.
     */
    async addParticipants(options) {
        const { issueIdOrKey, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/participant`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Removes participants from an existing customer request.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/participant-removeRequestParticipants
     * @param options Request options.
     */
    async removeParticipants(options) {
        const { issueIdOrKey, body, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/participant`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestSLAGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns the SLA information for a customer request for a given request Id/key.
     * A request can have zero or more SLA values.
     * Each SLA value can have zero or more "completed cycles" and zero or 1 "ongoing cycles".
     * Each cycle has information on when it started and stopped, and whether it breached the SLA goal.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/sla-getSlaInformation
     * @param options Request options.
     */
    async getInfo(options) {
        const { issueIdOrKey, start, limit, headers, errorStrategy } = options;
        const queryParams = { start, limit };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/sla`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns the SLA information for a customer request for a given request Id/key and SLA metric Id.
     * A request can have zero or more SLA values.
     * Each SLA value can have zero or more "completed cycles" and zero or 1 "ongoing cycles".
     * Each cycle has information on when it started and stopped, and whether it breached the SLA goal.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/sla-getSlaInformationById
     * @param options Request options.
     */
    async getInfoById(options) {
        const { issueIdOrKey, slaMetricId, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/sla/${encodeURIComponent(slaMetricId)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestStatusGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns the status transitions for a customer request for a given request Id/key.
     * The status transitions are returned in chronological order.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/status-getCustomerRequestStatus
     * @param options Request options.
     */
    async getStatus(options) {
        const { issueIdOrKey, start, limit, headers, errorStrategy } = options;
        const queryParams = { start, limit };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/status`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class RequestTransitionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns a list of transitions that customers can perform on the request.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/transition-getCustomerTransitions
     * @param options Request options.
     */
    async getTransitions(options) {
        const { issueIdOrKey, start, limit, headers, errorStrategy } = options;
        const queryParams = { start, limit };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/transition`, queryParams), constructHeaders(null, { 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Perform a customer transition for a given request and transition ID.
     * An optional comment can be included to provide a reason for the transition.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/transition-performCustomerTransition
     * @param options Request options.
     */
    async performTransition(options) {
        const { issueIdOrKey, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/servicedeskapi/request/${encodeURIComponent(issueIdOrKey)}/transition`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ServicedeskGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Request = new ServicedeskRequestGroup(implementation, this.getGlobalErrorStrategy);
        this.Customer = new ServicedeskCustomerGroup(implementation, this.getGlobalErrorStrategy);
        this.Organization = new ServicedeskOrganizationGroup(implementation, this.getGlobalErrorStrategy);
        this.Queue = new ServicedeskQueueGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
     * Returns all service projects in the Jira Service Management application with the option to include archived service projects.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk-getServiceDesks
     * @param options Request options.
     */
    async getServicedesks(options) {
        const { includeArchived, start, limit, headers, errorStrategy } = options ?? {};
        const queryParams = { includeArchived, start, limit };
        const request = new Request('GET', constructUrl('/rest/servicedeskapi/servicedesk', queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns the service project for a given service project Id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk-getServiceDeskById
     * @param options Request options.
     */
    async getServicedesk(options) {
        const { serviceDeskId, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Create one or more temporary attachments, which can later be converted into permanent attachments on Create attachment:
     * https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/request/{issueIdOrKey}/attachment
     * On successful execution, this resource will return a list of temporary attachment IDs, which are used in subsequent calls to convert the attachments into permanent attachments.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/attachTemporaryFile-attachTemporaryFile
     * @param options Request options.
     */
    async addTemporaryFile(options) {
        const { serviceDeskId, body, headers, errorStrategy } = options;
        const formBody = new FormData();
        formBody.setBufferImplementation(this.implementation);
        body.forEach(file => {
            formBody.append('file', new Blob(this.implementation, [file.content], {}), file.fileName);
        });
        const bodyBlob = formBody.getBlob();
        const request = new Request('POST', `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/attachTemporaryFile`, constructHeaders(bodyBlob, { 'X-ExperimentalApi': 'opt-in', ...headers }), bodyBlob);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ServicedeskCustomerGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Adds one or more existing customers to the given service project. If you need to create a customer, see Create customer:
     * https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/customer
     * Administer project permission is required, or agents if public signups and invites are enabled for the service project.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/customer-addCustomers
     * @param options Request options.
     */
    async addCustomers(options) {
        const { serviceDeskId, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/customer`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ServicedeskOrganizationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Adds an organization to a service project for a given service project id and organization id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/organization-addOrganization
     * @param options Request options.
     */
    async addOrganization(options) {
        const { serviceDeskId, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/organization`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Removes an organization from a service project for a given service project id and organization id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/organization-removeOrganization
     * @param options Request options.
     */
    async removeOrganization(options) {
        const { serviceDeskId, body, headers, errorStrategy } = options;
        const request = new Request('DELETE', `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/organization`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Returns all organizations within a service project for a given service project id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/organization-getOrganizations
     * @param options Request options.
     */
    async getOrganizations(options) {
        const { serviceDeskId, start, limit, headers, errorStrategy } = options;
        const queryParams = { start, limit };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/organization`, queryParams), constructHeaders(null, { 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ServicedeskQueueGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns a page of queues defined inside a service project, for a given service project ID.
     * The returned queues will include an issue count for each queue (represented in issueCount field) if the query param includeCount is set to true (defaults to false).
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-getQueues
     * @param options Request options.
     */
    async getQueues(options) {
        const { serviceDeskId, includeCount, start, limit, headers, errorStrategy } = options;
        const queryParams = { includeCount, start, limit };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/queue`, queryParams), constructHeaders(null, { 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a queue with the given properties.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-createQueue
     * @param options Request options.
     */
    async createQueue(options) {
        const { serviceDeskId, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/queue`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Reorder queues for the users. This is the order in which the queues will appear in agent view.
     * The API requires all queue ids to be passed in the new order.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-reorderQueues
     * @param options Request options.
     */
    async reorderQueues(options) {
        const { serviceDeskId, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/queue/reorder`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Updates the queue properties with the new properties. If a property is not passed it will not be updated.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-updateQueue
     * @param options Request options.
     */
    async updateQueue(options) {
        const { serviceDeskId, queueId, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/queue/${encodeURIComponent(queueId)}`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Delete the queue for the given queue id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-deleteQueue
     * @param options Request options.
     */
    async deleteQueue(options) {
        const { serviceDeskId, queueId, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/queue/${encodeURIComponent(queueId)}`, constructHeaders(null, { 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
     * Returns the queue for a given service project id and queue id.
     * The returned queue will include an issue count for queue (represented in issueCount field) if the query param includeCount is set to true (defaults to false).
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-getQueue
     * @param options Request options.
     */
    async getQueue(options) {
        const { serviceDeskId, queueId, includeCount, headers, errorStrategy } = options;
        const queryParams = { includeCount };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/queue/${encodeURIComponent(queueId)}`, queryParams), constructHeaders(null, { 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns a page of issues inside a queue for a given queue ID.
     * Only fields that the queue is configured to show are returned. For example, if a queue is configured to show only Description and Due Date, then only those two fields are returned for each issue in the queue.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/queue-getIssuesInQueue
     * @param options Request options.
     */
    async getIssuesInQueue(options) {
        const { serviceDeskId, queueId, start, limit, headers, errorStrategy } = options;
        const queryParams = { start, limit };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/queue/${encodeURIComponent(queueId)}/issue`, queryParams), constructHeaders(null, { 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ServicedeskRequestGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Type = new ServicedeskRequestTypeGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class ServicedeskRequestTypeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns all request types from a service project, for a given service project Id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype-getRequestTypes
     * @param options Request options.
     */
    async getTypes(options) {
        const { serviceDeskId, groupId, start, limit, headers, errorStrategy } = options;
        const queryParams = { groupId, start, limit };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttype`, queryParams), constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Creates a new request type for a given service project.
     * Certain fields cannot be specified on creation. These fields are given default values instead, as shown below.
     * Request Type icon - Question mark icon
     * Request Type groups - Empty, i.e. this request type will be hidden by default and not visible on the customer portal
     * Request Type status mapping - Empty, i.e. no custom status mapping
     * Request Type field mapping - Show the required fields as specified by the issue type
     * These fields can be updated after creation by a project administrator using the Agent view.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype-createRequestType
     * @param options Request options.
     */
    async createType(options) {
        const { serviceDeskId, body, headers, errorStrategy } = options;
        const request = new Request('POST', `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttype`, constructHeaders(body, { 'X-ExperimentalApi': 'opt-in', ...headers }), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns a request type for a given request type Id.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype-getRequestTypeById
     * @param options Request options.
     */
    async getType(options) {
        const { serviceDeskId, requestTypeId, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttype/${encodeURIComponent(requestTypeId)}`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns the fields for a request type, for a given request type Id and service project Id. These are the fields that are required to create a customer request of that particular request type.
     * In addition, the following information about the current user's permissions for the request type is returned:
     * * canRaiseOnBehalfOf field - Returns true, if the user has permission to raise requests on behalf of customers. Otherwise, returns false.
     * * canAddRequestParticipants field - Returns true, if the user can add request participants. Otherwise, returns false.
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttype/{requestTypeId}/field-getRequestTypeFields
     * @param options Request options.
     */
    async getFields(options) {
        const { serviceDeskId, requestTypeId, headers, errorStrategy } = options;
        const request = new Request('GET', `/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttype/${encodeURIComponent(requestTypeId)}/field`, constructHeaders(headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns all request type groups from a service project, for a given service project Id.
     * The groups will be in the same order as the order in which they appear on the customer portal
     * Documentation: https://docs.atlassian.com/jira-servicedesk/REST/4.22.0/#servicedeskapi/servicedesk/{serviceDeskId}/requesttypegroup-getRequestTypeGroups
     * @param options Request options.
     */
    async getTypeGroups(options) {
        const { serviceDeskId, start, limit, headers, errorStrategy } = options;
        const queryParams = { start, limit };
        const request = new Request('GET', constructUrl(`/rest/servicedeskapi/servicedesk/${encodeURIComponent(serviceDeskId)}/requesttypegroup`, queryParams), constructHeaders(null, { 'X-ExperimentalApi': 'opt-in', ...headers }));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
